@@ -275,6 +275,9 @@ class ORDF(Command):
     parser.add_option("--nocs", action="store_true",
                       dest="nocs", default=False,
                       help="Do not process changesets")
+    parser.add_option("--noprov", action="store_true",
+                      dest="noprov", default=False,
+                      help="Do not store provenance information")
     def parse_config(self):
         super(ORDF, self).parse_config()
 
@@ -340,16 +343,17 @@ class ORDF(Command):
                 if self.options.save:
                     g.parse(filename, format=self.options.format)
 
-                    proc = Process()
-                    proc.agent(agent)
-                    proto, rest = urllib.splittype(filename)
+                    if not self.options.noprov:
+                        proc = Process()
+                        proc.agent(agent)
+                        proto, rest = urllib.splittype(filename)
         
-                    if proto:
-                        src = URIRef(filename)
-                    else:
-                        src = URIRef("file://" + os.path.abspath(filename))
-                    proc.use(src)
-                    proc.result(g)
+                        if proto:
+                            src = URIRef(filename)
+                        else:
+                            src = URIRef("file://" + os.path.abspath(filename))
+                        proc.use(src)
+                        proc.result(g)
 
                     self.log.info("add %s" % (g.identifier,))
                     if self.options.nocs:
