@@ -161,3 +161,13 @@ def _init_ns():
     for entrypoint in pkg_resources.iter_entry_points(group="ordf.namespace"):
         init_ns = entrypoint.load()
         init_ns()
+
+    register_ns("sdmx", Namespace("http://purl.org/linked-data/sdmx#"))
+    register_ns("sdmxconcept", Namespace("http://purl.org/linked-data/sdmx/2009/concept#"))
+    register_ns("sdmxdim", Namespace("http://purl.org/linked-data/sdmx/2009/dimension#"))
+    register_ns("sdmxattr", Namespace("http://purl.org/linked-data/sdmx/2009/attribute#"))
+    register_ns("sdmxmeasure", Namespace("http://purl.org/linked-data/sdmx/2009/measure#"))
+    register_ns("sdmxcode", Namespace("http://purl.org/linked-data/sdmx/2009/code#"))
+    register_ns("sdmxsubject", Namespace("http://purl.org/linked-data/sdmx/2009/subject#"))
+
+    register_ns("wdrs", Namespace("http://www.w3.org/2007/05/powder-s#"))
